# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
try:
    import otg_pb2 as otg__pb2
except ImportError:
    from snappi import otg_pb2 as otg__pb2


class OpenapiStub(object):
    """Description missing in models

    For all RPCs defined in this service, API Server SHOULD provide JSON
    representation of `Error` message as an error string upon failure, ensuring
    name of enum constants (instead of value) for `kind` property is present
    in the representation
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetConfig = channel.unary_unary(
                '/otg.Openapi/SetConfig',
                request_serializer=otg__pb2.SetConfigRequest.SerializeToString,
                response_deserializer=otg__pb2.SetConfigResponse.FromString,
                )
        self.streamSetConfig = channel.stream_unary(
                '/otg.Openapi/streamSetConfig',
                request_serializer=otg__pb2.Data.SerializeToString,
                response_deserializer=otg__pb2.SetConfigResponse.FromString,
                )
        self.GetConfig = channel.unary_unary(
                '/otg.Openapi/GetConfig',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=otg__pb2.GetConfigResponse.FromString,
                )
        self.streamGetConfig = channel.unary_stream(
                '/otg.Openapi/streamGetConfig',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=otg__pb2.Data.FromString,
                )
        self.UpdateConfig = channel.unary_unary(
                '/otg.Openapi/UpdateConfig',
                request_serializer=otg__pb2.UpdateConfigRequest.SerializeToString,
                response_deserializer=otg__pb2.UpdateConfigResponse.FromString,
                )
        self.AppendConfig = channel.unary_unary(
                '/otg.Openapi/AppendConfig',
                request_serializer=otg__pb2.AppendConfigRequest.SerializeToString,
                response_deserializer=otg__pb2.AppendConfigResponse.FromString,
                )
        self.DeleteConfig = channel.unary_unary(
                '/otg.Openapi/DeleteConfig',
                request_serializer=otg__pb2.DeleteConfigRequest.SerializeToString,
                response_deserializer=otg__pb2.DeleteConfigResponse.FromString,
                )
        self.SetControlState = channel.unary_unary(
                '/otg.Openapi/SetControlState',
                request_serializer=otg__pb2.SetControlStateRequest.SerializeToString,
                response_deserializer=otg__pb2.SetControlStateResponse.FromString,
                )
        self.streamSetControlState = channel.stream_unary(
                '/otg.Openapi/streamSetControlState',
                request_serializer=otg__pb2.Data.SerializeToString,
                response_deserializer=otg__pb2.SetControlStateResponse.FromString,
                )
        self.SetControlAction = channel.unary_unary(
                '/otg.Openapi/SetControlAction',
                request_serializer=otg__pb2.SetControlActionRequest.SerializeToString,
                response_deserializer=otg__pb2.SetControlActionResponse.FromString,
                )
        self.streamSetControlAction = channel.stream_unary(
                '/otg.Openapi/streamSetControlAction',
                request_serializer=otg__pb2.Data.SerializeToString,
                response_deserializer=otg__pb2.SetControlActionResponse.FromString,
                )
        self.GetMetrics = channel.unary_unary(
                '/otg.Openapi/GetMetrics',
                request_serializer=otg__pb2.GetMetricsRequest.SerializeToString,
                response_deserializer=otg__pb2.GetMetricsResponse.FromString,
                )
        self.streamGetMetrics = channel.unary_stream(
                '/otg.Openapi/streamGetMetrics',
                request_serializer=otg__pb2.GetMetricsRequest.SerializeToString,
                response_deserializer=otg__pb2.Data.FromString,
                )
        self.GetStates = channel.unary_unary(
                '/otg.Openapi/GetStates',
                request_serializer=otg__pb2.GetStatesRequest.SerializeToString,
                response_deserializer=otg__pb2.GetStatesResponse.FromString,
                )
        self.streamGetStates = channel.unary_stream(
                '/otg.Openapi/streamGetStates',
                request_serializer=otg__pb2.GetStatesRequest.SerializeToString,
                response_deserializer=otg__pb2.Data.FromString,
                )
        self.GetCapture = channel.unary_unary(
                '/otg.Openapi/GetCapture',
                request_serializer=otg__pb2.GetCaptureRequest.SerializeToString,
                response_deserializer=otg__pb2.GetCaptureResponse.FromString,
                )
        self.streamGetCapture = channel.unary_stream(
                '/otg.Openapi/streamGetCapture',
                request_serializer=otg__pb2.GetCaptureRequest.SerializeToString,
                response_deserializer=otg__pb2.Data.FromString,
                )
        self.GetVersion = channel.unary_unary(
                '/otg.Openapi/GetVersion',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=otg__pb2.GetVersionResponse.FromString,
                )


class OpenapiServicer(object):
    """Description missing in models

    For all RPCs defined in this service, API Server SHOULD provide JSON
    representation of `Error` message as an error string upon failure, ensuring
    name of enum constants (instead of value) for `kind` property is present
    in the representation
    """

    def SetConfig(self, request, context):
        """Sets configuration resources on the traffic generator.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def streamSetConfig(self, request_iterator, context):
        """streaming version of the rpc SetConfig
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConfig(self, request, context):
        """Description missing in models
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def streamGetConfig(self, request, context):
        """streaming version of the rpc GetConfig
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateConfig(self, request, context):
        """Updates specific attributes of resources configured on the traffic generator. The
        fetched configuration shall reflect the updates applied successfully.
        The Response.Warnings in the Success response is available for implementers to disclose
        additional information about a state change including any implicit changes that are
        outside the scope of the state change.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AppendConfig(self, request, context):
        """Append new attributes of resources to existing configuration on the traffic generator.
        Resource names should not be part of existing configuration of that resource type;
        it should be unique for the operation to succeed. A failed append might leave the
        configuration in an undefined state and if the error is due to some invalid or unsupported
        configuration in the appended resources, it is expected that the user fix the error
        and  restart from SetConfig operation. The fetched configuration shall also reflect
        the new configuration applied successfully.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteConfig(self, request, context):
        """Delete attributes of resources from existing configuration on the traffic generator.
        Resource names should already be part of existing configuration of that resource
        type; for the operation to succeed. A failed delete will leave the configuration
        in an undefined state and if the error is due to some invalid or unsupported configuration
        in the deleted  resources, it is expected that the user fix the error and restart
        from SetConfig operation. On successful deletion the fetched configuration shall
        not reflect the removed configuration.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetControlState(self, request, context):
        """Sets the operational state of configured resources.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def streamSetControlState(self, request_iterator, context):
        """streaming version of the rpc SetControlState
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetControlAction(self, request, context):
        """Triggers actions against configured resources.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def streamSetControlAction(self, request_iterator, context):
        """streaming version of the rpc SetControlAction
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMetrics(self, request, context):
        """Description missing in models
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def streamGetMetrics(self, request, context):
        """streaming version of the rpc GetMetrics
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStates(self, request, context):
        """Description missing in models
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def streamGetStates(self, request, context):
        """streaming version of the rpc GetStates
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCapture(self, request, context):
        """Description missing in models
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def streamGetCapture(self, request, context):
        """streaming version of the rpc GetCapture
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVersion(self, request, context):
        """Description missing in models
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OpenapiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.SetConfig,
                    request_deserializer=otg__pb2.SetConfigRequest.FromString,
                    response_serializer=otg__pb2.SetConfigResponse.SerializeToString,
            ),
            'streamSetConfig': grpc.stream_unary_rpc_method_handler(
                    servicer.streamSetConfig,
                    request_deserializer=otg__pb2.Data.FromString,
                    response_serializer=otg__pb2.SetConfigResponse.SerializeToString,
            ),
            'GetConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConfig,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=otg__pb2.GetConfigResponse.SerializeToString,
            ),
            'streamGetConfig': grpc.unary_stream_rpc_method_handler(
                    servicer.streamGetConfig,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=otg__pb2.Data.SerializeToString,
            ),
            'UpdateConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateConfig,
                    request_deserializer=otg__pb2.UpdateConfigRequest.FromString,
                    response_serializer=otg__pb2.UpdateConfigResponse.SerializeToString,
            ),
            'AppendConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.AppendConfig,
                    request_deserializer=otg__pb2.AppendConfigRequest.FromString,
                    response_serializer=otg__pb2.AppendConfigResponse.SerializeToString,
            ),
            'DeleteConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteConfig,
                    request_deserializer=otg__pb2.DeleteConfigRequest.FromString,
                    response_serializer=otg__pb2.DeleteConfigResponse.SerializeToString,
            ),
            'SetControlState': grpc.unary_unary_rpc_method_handler(
                    servicer.SetControlState,
                    request_deserializer=otg__pb2.SetControlStateRequest.FromString,
                    response_serializer=otg__pb2.SetControlStateResponse.SerializeToString,
            ),
            'streamSetControlState': grpc.stream_unary_rpc_method_handler(
                    servicer.streamSetControlState,
                    request_deserializer=otg__pb2.Data.FromString,
                    response_serializer=otg__pb2.SetControlStateResponse.SerializeToString,
            ),
            'SetControlAction': grpc.unary_unary_rpc_method_handler(
                    servicer.SetControlAction,
                    request_deserializer=otg__pb2.SetControlActionRequest.FromString,
                    response_serializer=otg__pb2.SetControlActionResponse.SerializeToString,
            ),
            'streamSetControlAction': grpc.stream_unary_rpc_method_handler(
                    servicer.streamSetControlAction,
                    request_deserializer=otg__pb2.Data.FromString,
                    response_serializer=otg__pb2.SetControlActionResponse.SerializeToString,
            ),
            'GetMetrics': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMetrics,
                    request_deserializer=otg__pb2.GetMetricsRequest.FromString,
                    response_serializer=otg__pb2.GetMetricsResponse.SerializeToString,
            ),
            'streamGetMetrics': grpc.unary_stream_rpc_method_handler(
                    servicer.streamGetMetrics,
                    request_deserializer=otg__pb2.GetMetricsRequest.FromString,
                    response_serializer=otg__pb2.Data.SerializeToString,
            ),
            'GetStates': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStates,
                    request_deserializer=otg__pb2.GetStatesRequest.FromString,
                    response_serializer=otg__pb2.GetStatesResponse.SerializeToString,
            ),
            'streamGetStates': grpc.unary_stream_rpc_method_handler(
                    servicer.streamGetStates,
                    request_deserializer=otg__pb2.GetStatesRequest.FromString,
                    response_serializer=otg__pb2.Data.SerializeToString,
            ),
            'GetCapture': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCapture,
                    request_deserializer=otg__pb2.GetCaptureRequest.FromString,
                    response_serializer=otg__pb2.GetCaptureResponse.SerializeToString,
            ),
            'streamGetCapture': grpc.unary_stream_rpc_method_handler(
                    servicer.streamGetCapture,
                    request_deserializer=otg__pb2.GetCaptureRequest.FromString,
                    response_serializer=otg__pb2.Data.SerializeToString,
            ),
            'GetVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVersion,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=otg__pb2.GetVersionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'otg.Openapi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Openapi(object):
    """Description missing in models

    For all RPCs defined in this service, API Server SHOULD provide JSON
    representation of `Error` message as an error string upon failure, ensuring
    name of enum constants (instead of value) for `kind` property is present
    in the representation
    """

    @staticmethod
    def SetConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/otg.Openapi/SetConfig',
            otg__pb2.SetConfigRequest.SerializeToString,
            otg__pb2.SetConfigResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def streamSetConfig(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/otg.Openapi/streamSetConfig',
            otg__pb2.Data.SerializeToString,
            otg__pb2.SetConfigResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/otg.Openapi/GetConfig',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            otg__pb2.GetConfigResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def streamGetConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/otg.Openapi/streamGetConfig',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            otg__pb2.Data.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/otg.Openapi/UpdateConfig',
            otg__pb2.UpdateConfigRequest.SerializeToString,
            otg__pb2.UpdateConfigResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AppendConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/otg.Openapi/AppendConfig',
            otg__pb2.AppendConfigRequest.SerializeToString,
            otg__pb2.AppendConfigResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/otg.Openapi/DeleteConfig',
            otg__pb2.DeleteConfigRequest.SerializeToString,
            otg__pb2.DeleteConfigResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetControlState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/otg.Openapi/SetControlState',
            otg__pb2.SetControlStateRequest.SerializeToString,
            otg__pb2.SetControlStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def streamSetControlState(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/otg.Openapi/streamSetControlState',
            otg__pb2.Data.SerializeToString,
            otg__pb2.SetControlStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetControlAction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/otg.Openapi/SetControlAction',
            otg__pb2.SetControlActionRequest.SerializeToString,
            otg__pb2.SetControlActionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def streamSetControlAction(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/otg.Openapi/streamSetControlAction',
            otg__pb2.Data.SerializeToString,
            otg__pb2.SetControlActionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMetrics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/otg.Openapi/GetMetrics',
            otg__pb2.GetMetricsRequest.SerializeToString,
            otg__pb2.GetMetricsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def streamGetMetrics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/otg.Openapi/streamGetMetrics',
            otg__pb2.GetMetricsRequest.SerializeToString,
            otg__pb2.Data.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetStates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/otg.Openapi/GetStates',
            otg__pb2.GetStatesRequest.SerializeToString,
            otg__pb2.GetStatesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def streamGetStates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/otg.Openapi/streamGetStates',
            otg__pb2.GetStatesRequest.SerializeToString,
            otg__pb2.Data.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCapture(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/otg.Openapi/GetCapture',
            otg__pb2.GetCaptureRequest.SerializeToString,
            otg__pb2.GetCaptureResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def streamGetCapture(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/otg.Openapi/streamGetCapture',
            otg__pb2.GetCaptureRequest.SerializeToString,
            otg__pb2.Data.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/otg.Openapi/GetVersion',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            otg__pb2.GetVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import pytest


def test_lag(api):
    """Test LAG functionality
    """
    config = api.config()

    # setup port container
    p1, p2, p3 = (config.ports
        .port(name='p1')
        .port(name='p2')
        .port(name='p3')
    )

    # setup lag container
    l1 = config.lags.lag(name='l1')[-1]
    lacp = l1.protocol.lacp
    for port in config.ports:
        lp = l1.ports.port(port_name=port.name)[-1]
        lp.ethernet.name = 'lpe {}'.format(port.name)
        lp.ethernet.mac = '00:00:01:00:00:01'
        lacp.actor_system_id = '00:00:0A:00:00:01'
        lacp.actor_key = 1
        lp.lacp.actor_port_number = 10

    api.set_config(config)


if __name__ == '__main__':
    pytest.main(['-s', __file__])



# snappi-test.py

# This script creates the traffic going over the N3 GTPu interface between
# the gNB and the UPF nodes of a 5G core network.
# Refer : https://medium.com/@derekcheung/5gc-part-3-user-plane-and-gtp-u-tunnels-53319463967
#
#
# N ports (representing users) and N ports (representing servers)
# M GTP tunnels originating and terminating on each port.  Each tunnel represents one UE (mobile phone)
# Assume that
#   N = M for the sake of simplicity
#   Total traffic required in each direction is 5 Gbps
#   Each port is able to send and receive 1 Gbps
#   --> Test will need 5 ports.  Each port will send traffic over 5 GTP tunnels
#   --> Each tunnel (hence each UE) will send at the rate of ~200Mbps (1Gbps/5)
#
#                   T[1]
#       P[1]  <------------------------> P[6]
#                   T[2]
#             <------------------------> P[7]
#                   T[3]
#             <------------------------> P[8]
#      ....
#                   T[5]
#             <------------------------> P[10]
#
#
#
#                   T[6]
#       P[2]  <------------------------> P[6]
#                   T[7]
#             <------------------------> P[7]
#      ....
#
#
#                   T[21]
#       P[5]  <------------------------> P[6]
#                   T[22]
#             <------------------------> P[7]
#      ....

# We represent this scenario using one flow on each port and
# use a list to represent the UE IP addresses and the GTP tunnel IDs.
# Packets have the following headers: Ethernet, IP, UDP, GTPv1, IP
# Frame size is 128

import pytest
import yaml
import json
import collections

# these test parameters would normally come from a test infrastructure file
d = yaml.safe_load(
    """
# gnb_mac_addr This is the MAC SA for uplink packets & MAC DA for downlink packets
# n3_mac_addr This is the MAC DA for uplink packets & MAC SA for downlink packets
globals:
  gnb_mac_addr: AA BB CC DD EE FF 
  n3_mac_addr: FF EE DD CC BB AA
  gnb_ip_addr: 10.20.31.10
  upf_ip_addr: 10.20.31.3
  inner_ip_src_dst: 172.217.5.68
  gtp_tunnels: 5

users:
  - location: localuhd/1
    teid: 0
    ue_ip: 1.1.1.1
  - location: localuhd/2
    teid: 25
    ue_ip: 1.1.2.1

servers:
  - location: localuhd/1
    teid: 1000
    ue_ip: 1.1.100.1
  - location: localuhd/2
    teid: 1025
    ue_ip: 1.1.101.1
"""
)
d = json.dumps(d)
test_params = json.loads(
    d, object_hook=lambda d: collections.namedtuple("X", d.keys())(*d.values())
)


def test_gtpu(api):
    global test_params
    config = api.config()

    for user, server in zip(test_params.users, test_params.servers):
        config.ports.port(
            name="User Port %s" % user.location, location=user.location
        ).port(name="Server Port %s" % server.location, location=server.location)
        tx_port = config.ports[-2]
        rx_port = config.ports[-1]
        create_flow(
            config,
            "Uplink",
            user,
            server,
            tx_port,
            rx_port,
            test_params.globals.gnb_mac_addr.replace(" ", ":"),
            test_params.globals.n3_mac_addr.replace(" ", ":"),
            test_params.globals.gnb_ip_addr,
            test_params.globals.upf_ip_addr,
            user.ue_ip,
            test_params.globals.inner_ip_src_dst,
            test_params.globals.gtp_tunnels,
        )
        create_flow(
            config,
            "Downlink",
            server,
            user,
            tx_port,
            rx_port,
            test_params.globals.n3_mac_addr.replace(" ", ":"),
            test_params.globals.gnb_mac_addr.replace(" ", ":"),
            test_params.globals.upf_ip_addr,
            test_params.globals.gnb_ip_addr,
            test_params.globals.inner_ip_src_dst,
            server.ue_ip,
            test_params.globals.gtp_tunnels,
        )

    api.set_config(config)


def create_flow(
    config,
    flow_prefix,
    src_param,
    dst_param,
    tx_port,
    rx_port,
    src_mac,
    dst_mac,
    outer_ip_src,
    outer_ip_dst,
    inner_ip_src,
    inner_ip_dst,
    gtp_tunnels,
):
    flow_name = "%s %s -> %s" % (flow_prefix, tx_port.name, rx_port.name)
    flow = config.flows.flow(name=flow_name)[-1]
    flow.tx_rx.port.tx_name = tx_port.name
    flow.tx_rx.port.rx_name = rx_port.name

    flow.packet.ethernet().ipv4().udp().gtpv1().ipv4()
    eth, outer_ip, udp, gtp, inner_ip = flow.packet

    eth.src.value = src_mac
    eth.dst.value = dst_mac
    outer_ip.src.value = outer_ip_src
    outer_ip.dst.value = outer_ip_dst
    gtp.teid.increment.start = src_param.teid
    gtp.teid.increment.step = 1
    gtp.teid.increment.count = gtp_tunnels
    inner_ip.src.value = inner_ip_src
    inner_ip.dst.value = inner_ip_dst
    gtp.teid.metric_tags.add(name="gtp_teid")

    flow.size.fixed = 128
    flow.rate.gbps = 1
    flow.duration.fixed_packets.packets = 100000


if __name__ == "__main__":
    pytest.main(["-vv", "-s", __file__])



import pytest


def get_mock_config(grpc_api):
    """Test Metric Tag"""
    # create a new config object
    test_const = {
        "mac1": ["00:00:01:01:01:01", "00:00:01:01:01:02"],
        "mac2": ["00:00:01:01:01:03", "00:00:01:01:01:04"],
        "mac3": ["00:00:01:01:01:05", "00:00:01:01:01:06"],
        "ip1": ["1.1.1.1", "1.1.1.2"],
        "ip2": ["1.1.1.3", "1.1.1.4"],
        "ip3": ["1.1.1.5", "1.1.1.6"],
        "tcpPortValue": 80,
    }

    config = grpc_api.config()

    tx_port, rx_port = config.ports.port(
        name="Tx Port", location="10.36.74.26;02;13"
    ).port(name="Rx Port", location="10.36.74.26;02;14")

    flow = config.flows.flow(name="Tx -> Rx Flow")[0]
    flow.tx_rx.port.tx_name = tx_port.name
    flow.tx_rx.port.rx_name = rx_port.name
    flow.size.fixed = 128
    flow.rate.pps = 1000
    flow.duration.fixed_packets.packets = 10000

    ethIngress, vlanIngress, ipIngress, tcpIngress = (
        flow.packet.ethernet().vlan().ipv4().tcp()
    )

    ethIngress.src.values = test_const["mac1"]
    ethIngress.dst.values = test_const["mac2"]
    ipIngress.src.values = test_const["ip1"]
    ipIngress.dst.values = test_const["ip2"]
    tcpIngress.src_port.value = test_const["tcpPortValue"]
    tcpIngress.dst_port.value = test_const["tcpPortValue"]
    ethIngress.dst.metric_tags.add(name="eth_dst_ingress", offset=40, length=8)
    ipIngress.dst.metric_tags.add(name="ip_dst_ingress", offset=24, length=8)

    ethEgress, ipEgress, tcpEgress = flow.egress_packet.ethernet().ipv4().tcp()

    ethEgress.src.values = test_const["mac2"]
    ethEgress.dst.values = test_const["mac3"]
    ipEgress.src.values = test_const["ip2"]
    ipEgress.dst.values = test_const["ip3"]
    tcpEgress.src_port.value = test_const["tcpPortValue"]
    tcpEgress.dst_port.value = test_const["tcpPortValue"]
    ethEgress.dst.metric_tags.add(name="eth_dst_egress", offset=40, length=8)
    ipEgress.dst.metric_tags.add(name="ip_dst_egress", offset=24, length=8)

    return config


def test_grpc_set_config(grpc_api):
    config = get_mock_config(grpc_api)
    response = grpc_api.set_config(config)
    assert len(response.warnings) == 1
    assert response.warnings[0] == "no"


def test_grpc_get_config(grpc_api):
    config = get_mock_config(grpc_api)
    response = grpc_api.get_config()
    assert config.serialize() == response.serialize()


if __name__ == "__main__":
    pytest.main(["-vv", "-s", __file__])



"""
To build distribution: python setup.py sdist bdist_wheel --universal
"""
import os
import setuptools
from version import Version

pkg_name = Version.package_name
version = Version.version
models_version = Version.models_version

# read long description from readme.md
base_dir = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(base_dir, "readme.md")) as fd:
    long_description = fd.read()

with open("models-release", "w") as out:
    out.write("v" + models_version)

install_requires = []
with open(os.path.join(base_dir, "requirements.txt"), "r+") as fd:
    install_requires = fd.readlines()
    install_requires = install_requires[1:]

setuptools.setup(
    name=pkg_name,
    version=version,
    description="The Snappi Open Traffic Generator Python Package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/open-traffic-generator/snappi",
    author="ajbalogh",
    author_email="andy.balogh@keysight.com",
    license="MIT",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Testing :: Traffic Generation",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
    ],
    keywords="snappi testing open traffic generator automation",
    include_package_data=True,
    packages=[pkg_name],
    python_requires=">=2.7, <4",
    install_requires=install_requires,
    extras_require={
        "ixnetwork": ["snappi_ixnetwork==1.31.0"],
        "trex": ["snappi_trex"],
        "testing": ["pytest", "flask"],
    },
)
